@@ -14,13 +14,16 @@ mkdir $srcdir/zip-files
 
 extensiondir=$installdir/share/gnome-shell/extensions
 schemadir=$installdir/share/glib-2.0/schemas
-localedir=$installdir/share/locale
 
 for f in $extensiondir/*; do
   name=`basename ${f%%@*}`
   uuid=$name@gnome-shell-extensions.gcampax.github.com
   schema=$schemadir/org.gnome.shell.extensions.$name.gschema.xml
 
+  olddomain=gnome-shell-extensions
+  newdomain=gnome-shell-extension-$name
+  sed -i "/gettext-domain/ s:$olddomain:$newdomain:" $f/metadata.json
+
   xgettext --from-code=UTF-8 --output-dir=$builddir --output=$name.pot $f/*.js
 
   if [ -f $builddir/$name.pot ]; then
